# -*- encoding: utf-8 -*-

from django.db import models
from django.conf import settings
from models import Parent, PermissionMeta, Region, Adresse, Personne

I_ETAT_CHOICES = ((0, "Jamais ouverte ou fermée"),
                  (1, "Active (budget + local + personnel + accès pour le public)"),
                  (2, "Ouverture imminente (budget + local en construction " + \
                          "ou personnel en cours de recrutement)"),
                  (3, "En projet (budget)"))

I_CONVENTION_CHOICES = (("2", "--"), ("0", "Non"), ("1", "Oui"))


class TypeImplantation(Parent):
    __metaclass__ = PermissionMeta

    id = models.SmallIntegerField(primary_key=True)
    nom = models.CharField(max_length=255)
    nom_court = models.CharField(max_length=3)
    def __unicode__ (self):
        return self.nom
    class Meta:
        #db_table = u'type_implantations'
        ordering = ["nom",]

class Implantation(Parent):
    __metaclass__ = PermissionMeta

    id = models.AutoField(primary_key=True,
            db_column='id_implantation', editable=False)
    responsables = models.ManyToManyField(Personne, through='ResponsableImplantation')
    etat = models.SmallIntegerField(choices = I_ETAT_CHOICES,
                                    verbose_name = 'État de l\'implantation')
    commentaire_etat = models.TextField(max_length=256, blank=True,
            null=True, verbose_name = 'Commentaire concernant l\'état de ' +
            'l\'implantation ou son évolution')
    nom = models.CharField(max_length=256,
                           verbose_name = 'Nom complet de l\'implantation')
    nom_long = models.CharField(max_length=36,
                                verbose_name = 'Nom long de l\'implantation')
    nom_court = models.CharField(max_length=20,
                                 verbose_name = 'Nom court de l\'implantation')
    type = models.ForeignKey(TypeImplantation,
                             verbose_name = 'Type d\'implantation')
    bureau_rattachement = models.ForeignKey('Implantation',
                                            verbose_name = 'Bureau de rattachement', 
                                            blank=True, null=True)
    region = models.ForeignKey(Region,
                               verbose_name = 'Région de l\'AUF')
    adresse_postale = models.OneToOneField (Adresse, related_name='adr_postale')
    adresse_physique = models.OneToOneField (Adresse, related_name='adr_physique')
    telephone_publique = models.CharField(max_length=20, blank=True, null=True,
            verbose_name = 'Téléphone (pour diffusion publique)')
    telephone_interne = models.CharField(max_length=20, blank=True, null=True,
            verbose_name = 'Téléphone (pour diffusion interne seulement)')
    fax_publique = models.CharField(max_length=20, blank=True, null=True,
            verbose_name = 'Télécopieur (pour diffusion publique)')
    fax_interne = models.CharField(max_length=20, blank=True, null=True,
            verbose_name = 'Télécopieur (pour diffusion interne seulement)')
    courriel_publique = models.CharField(max_length=64, blank=True, null=True,
            verbose_name = 'Courriel (pour diffusion publique)')
    courriel_interne = models.CharField(max_length=64, blank=True, null=True,
            verbose_name = 'Courriel (pour diffusion interne seulement)')
    url = models.CharField(max_length=64, blank=True, null=True,
            verbose_name = 'Adresse du site Web')
    date_ouverture = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Date d\'ouverture')
    date_inauguration = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Date d\'inauguration')
    date_extension = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Date d\'extension')
    date_fermeture = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Date de fermeture')
    date_derniere_modif = models.CharField(max_length=10, blank=True,
            null=True, verbose_name = 'Derniere mise a jour')
    hebergement_etablissement = models.CharField(max_length=256, blank=True,
           null=True, verbose_name = 'Établissement d\'hébergement')
    hebergement_convention = models.CharField(max_length = 1, default="0",
            choices=I_CONVENTION_CHOICES,
            verbose_name = 'Convention d\'hébergement de l\'implantation')
    accord_siege = models.TextField(blank=True, null=True)
    hebergement_date_convention = models.CharField(max_length=10, blank=True,
            null=True, verbose_name = 'Date de la convention d\'hébergement')
    fuseau_horaire = models.CharField(max_length=4, blank=True, null=True,
            verbose_name = 'Fuseau horaire')
    code_meteo = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Code météo')
    remarques = models.TextField(max_length=512, blank=True, null=True,
            verbose_name = 'Remarques')
    latitude = models.FloatField (null=True, blank=True)
    longitude = models.FloatField (null=True, blank=True)

    def __unicode__ (self):
        return self.nom_complet

    class Meta:
        #db_table = u'implantations'
        ordering = ['nom_complet']


class ResponsableImplantation(Parent):
    __metaclass__ = PermissionMeta
    implantation = models.ForeignKey(Implantation)
    personne = models.ForeignKey(Personne)
    poste = models.CharField(max_length=64, blank=True, null=True)
    complement = models.CharField(max_length=64, blank=True, null=True)

    def __unicode__(self):
        return "<RI %s %s -> %s>" % (self.personne.prenom, self.personne.nom, 
                                     self.implantation.nom_complet)
